@@ -211,24 +211,7 @@ static SDL_Surface* Create_SDL_Surface_From_CGImage_RGB(CGImageRef image_ref)
 
     CGContextRef bitmap_context;
     CGBitmapInfo bitmap_info;
-
-    /* This sets up a color space that results in identical values
-     * as the image data itself, which is the same as the standalone
-     * libpng loader.
-     * Thanks to Allegro. :)
-     */
-    CGFloat whitePoint[3] = { 0.950, 1.000, 1.089 };
-    CGFloat blackPoint[3] = { 0.000, 0.000, 0.000 };
-    CGFloat gamma[3] = { 2.2, 2.2, 2.2 };
-    CGFloat matrix[9] = {
-        0.412, 0.213, 0.019,
-        0.358, 0.715, 0.119,
-        0.180, 0.072, 0.950
-    };
-    CGColorSpaceRef color_space =
-        CGColorSpaceCreateCalibratedRGB(
-                                    whitePoint, blackPoint, gamma, matrix
-                                    );
+    CGColorSpaceRef color_space = CGColorSpaceCreateDeviceRGB();
 
     if (alpha == kCGImageAlphaNone ||
         alpha == kCGImageAlphaNoneSkipFirst ||
@@ -406,7 +389,7 @@ static int Internal_isType_UIImage (SDL_RWops *rw_ops, CFStringRef uti_string_to
     int is_type = 0;
 
 #if defined(ALLOW_UIIMAGE_FALLBACK) && ((TARGET_OS_IPHONE == 1) || (TARGET_IPHONE_SIMULATOR == 1))
-    int start = SDL_RWtell(rw_ops);
+    Sint64 start = SDL_RWtell(rw_ops);
     if ((0 == CFStringCompare(uti_string_to_test, kUTTypeICO, 0)) ||
         (0 == CFStringCompare(uti_string_to_test, CFSTR("com.microsoft.cur"), 0))) {
 
@@ -521,7 +504,7 @@ static int Internal_isType_UIImage (SDL_RWops *rw_ops, CFStringRef uti_string_to
         }
     }
 
-    // reset the file descption pointer
+    // reset the file pointer
     SDL_RWseek(rw_ops, start, SEEK_SET);
 
 #endif  /* #if defined(ALLOW_UIIMAGE_FALLBACK) && ((TARGET_OS_IPHONE == 1) || (TARGET_IPHONE_SIMULATOR == 1)) */
@@ -532,6 +515,7 @@ static int Internal_isType_ImageIO (SDL_RWops *rw_ops, CFStringRef uti_string_to
 {
     int is_type = 0;
 
+    Sint64 start = SDL_RWtell(rw_ops);
     CFDictionaryRef hint_dictionary = CreateHintDictionary(uti_string_to_test);
     CGImageSourceRef image_source = CreateCGImageSourceFromRWops(rw_ops, hint_dictionary);
 
@@ -540,6 +524,8 @@ static int Internal_isType_ImageIO (SDL_RWops *rw_ops, CFStringRef uti_string_to
     }
 
     if (NULL == image_source) {
+        // reset the file pointer
+        SDL_RWseek(rw_ops, start, SEEK_SET);
         return 0;
     }
 
@@ -555,6 +541,9 @@ static int Internal_isType_ImageIO (SDL_RWops *rw_ops, CFStringRef uti_string_to
     is_type = (int)UTTypeConformsTo(uti_string_to_test, uti_type);
 
     CFRelease(image_source);
+
+    // reset the file pointer
+    SDL_RWseek(rw_ops, start, SEEK_SET);
     return is_type;
 }
 
